searchData={"items":[{"type":"module","title":"Purl","doc":"Elixir Implementation of the purl (package url) specification.","ref":"Purl.html"},{"type":"module","title":"Specification - Purl","doc":"https://github.com/package-url/purl-spec\n\n**Format**: `pkg:type/namespace/name@version?qualifiers#subpath`\n\n> #### License {: .neutral}\n>\n> A lot of the documentation was taken directly from the specification. It is\n> licensed under the MIT License:\n> ```\n> Copyright (c) the purl authors\n>\n> Permission is hereby granted, free of charge, to any person obtaining a copy of\n> this software and associated documentation files (the \"Software\"), to deal in\n> the Software without restriction, including without limitation the rights to\n> use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of\n> the Software, and to permit persons to whom the Software is furnished to do so,\n> subject to the following conditions:\n>\n> The above copyright notice and this permission notice shall be included in all\n> copies or substantial portions of the Software.\n>\n> THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n> IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS\n> FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\n> COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER\n> IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN\n> CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n> ```","ref":"Purl.html#module-specification"},{"type":"function","title":"Purl.from_resource_uri/1","doc":"Convert known URLs to purl","ref":"Purl.html#from_resource_uri/1"},{"type":"function","title":"Currently Supported - Purl.from_resource_uri/1","doc":"* GitHub: Repository HTTP / Git URL, Project URL\n* BitBucket: Repository HTTTP / Git URL, Project URL\n* Hex.pm package URL","ref":"Purl.html#from_resource_uri/1-currently-supported"},{"type":"type","title":"Purl.name/0","doc":"the name of the package","ref":"Purl.html#t:name/0"},{"type":"type","title":"Purl.namespace/0","doc":"some name prefix such as a Maven groupid, a Docker image owner, a GitHub user\nor organization\n\nThe values are type-specific.","ref":"Purl.html#t:namespace/0"},{"type":"type","title":"Purl.namespace_segment/0","doc":"Segment of the namespace","ref":"Purl.html#t:namespace_segment/0"},{"type":"type","title":"Validation - Purl.namespace_segment/0","doc":"* must not contain a '/'\n* must not be empty\n* A URL host or Authority must NOT be used as a namespace. Use instead a\n`repository_url` qualifier. Note however that for some types, the namespace\nmay look like a host.","ref":"Purl.html#t:namespace_segment/0-validation"},{"type":"function","title":"Purl.new/1","doc":"Creates a new purl struct from a `Purl`, `URI` or string.","ref":"Purl.html#new/1"},{"type":"function","title":"Examples - Purl.new/1","doc":"iex> Purl.new(\"pkg:hex/purl\")\n    {:ok, %Purl{type: \"hex\", name: \"purl\"}}","ref":"Purl.html#new/1-examples"},{"type":"function","title":"Purl.new!/1","doc":"Similar to `new/1` but raises `URI.Error`, `Purl.Error.InvalidField` or\n`Purl.Error.InvalidURI` if an invalid input is given.","ref":"Purl.html#new!/1"},{"type":"function","title":"Examples - Purl.new!/1","doc":"iex> Purl.new!(\"pkg:hex/purl\")\n    %Purl{type: \"hex\", name: \"purl\"}\n\n    iex> Purl.new!(\">pkg:hex/purl\")\n    ** (URI.Error) cannot parse due to reason invalid_uri: \">\"\n\n    iex> Purl.new!(\"pkg:hex*/purl\")\n    ** (Purl.Error.InvalidField) invalid field type, \"hex*\" given","ref":"Purl.html#new!/1-examples"},{"type":"type","title":"Purl.parse_error/0","doc":"","ref":"Purl.html#t:parse_error/0"},{"type":"type","title":"Purl.qualifier_key/0","doc":"qualifier key","ref":"Purl.html#t:qualifier_key/0"},{"type":"type","title":"Validation - Purl.qualifier_key/0","doc":"* The key must be composed only of ASCII letters and numbers, '.', '-' and '_' (period, dash and underscore)\n* A key cannot start with a number\n* A key must NOT be percent-encoded\n* A key is case insensitive. The canonical form is lowercase\n* A key cannot contains spaces","ref":"Purl.html#t:qualifier_key/0-validation"},{"type":"type","title":"Purl.qualifier_value/0","doc":"qualifier value","ref":"Purl.html#t:qualifier_value/0"},{"type":"type","title":"Validation - Purl.qualifier_value/0","doc":"* value cannot be an empty string: a key=value pair with an empty value is the\nsame as no key/value at all for this key","ref":"Purl.html#t:qualifier_value/0-validation"},{"type":"type","title":"Purl.qualifiers/0","doc":"extra qualifying data for a package such as an OS, architecture, a distro,\netc.\n\nThe values are type-specific.","ref":"Purl.html#t:qualifiers/0"},{"type":"type","title":"Validation - Purl.qualifiers/0","doc":"* key must be unique within the keys of the qualifiers string","ref":"Purl.html#t:qualifiers/0-validation"},{"type":"type","title":"Purl.subpath/0","doc":"extra subpath within a package, relative to the package root","ref":"Purl.html#t:subpath/0"},{"type":"type","title":"Purl.subpath_segment/0","doc":"subpath segment","ref":"Purl.html#t:subpath_segment/0"},{"type":"type","title":"Validation - Purl.subpath_segment/0","doc":"* must not contain a '/'\n* must not be any of '..' or '.'\n* must not be empty","ref":"Purl.html#t:subpath_segment/0-validation"},{"type":"type","title":"Purl.t/0","doc":"Package URL struct","ref":"Purl.html#t:t/0"},{"type":"function","title":"Purl.to_string/1","doc":"Formats purl as string","ref":"Purl.html#to_string/1"},{"type":"function","title":"Examples - Purl.to_string/1","doc":"iex> Purl.to_string(%Purl{type: \"hex\", name: \"purl\"})\n    \"pkg:hex/purl\"","ref":"Purl.html#to_string/1-examples"},{"type":"function","title":"Purl.to_uri/1","doc":"Converts a purl to a `URI`","ref":"Purl.html#to_uri/1"},{"type":"function","title":"Examples - Purl.to_uri/1","doc":"iex> Purl.to_uri(%Purl{type: \"hex\", name: \"purl\"})\n    %URI{scheme: \"pkg\", path: \"hex/purl\"}","ref":"Purl.html#to_uri/1-examples"},{"type":"type","title":"Purl.type/0","doc":"the package \"type\" or package \"protocol\" such as `maven`, `npm`, `nuget`,\n`gem`, `pypi`, etc.\n\nKnown types: https://github.com/package-url/purl-spec/blob/master/PURL-TYPES.rst","ref":"Purl.html#t:type/0"},{"type":"type","title":"Validation - Purl.type/0","doc":"* The package type is composed only of ASCII letters and numbers, '.', '+' and '-' (period, plus, and dash)\n* The type cannot start with a number\n* The type cannot contains spaces\n* The type must NOT be percent-encoded\n* The type is case insensitive. The canonical form is lowercase","ref":"Purl.html#t:type/0-validation"},{"type":"type","title":"Purl.version/0","doc":"the version of the package\n\nA version is a plain and opaque string. Some package types use versioning\nconventions such as semver for NPMs or nevra conventions for RPMS. A type may\ndefine a procedure to compare and sort versions, but there is no reliable and\nuniform way to do such comparison consistently.","ref":"Purl.html#t:version/0"},{"type":"exception","title":"Purl.Error.DuplicateQualifier","doc":"Error raised if qualifier keys are duplicated","ref":"Purl.Error.DuplicateQualifier.html"},{"type":"type","title":"Purl.Error.DuplicateQualifier.t/0","doc":"","ref":"Purl.Error.DuplicateQualifier.html#t:t/0"},{"type":"exception","title":"Purl.Error.InvalidField","doc":"Error raised in field values are invalid","ref":"Purl.Error.InvalidField.html"},{"type":"type","title":"Purl.Error.InvalidField.t/0","doc":"","ref":"Purl.Error.InvalidField.html#t:t/0"},{"type":"exception","title":"Purl.Error.InvalidScheme","doc":"Error raised if the scheme of the purl is incorrect","ref":"Purl.Error.InvalidScheme.html"},{"type":"type","title":"Purl.Error.InvalidScheme.t/0","doc":"","ref":"Purl.Error.InvalidScheme.html#t:t/0"},{"type":"exception","title":"Purl.Error.SpecialCaseFailed","doc":"Error raised if special rules for type are not fulfilled","ref":"Purl.Error.SpecialCaseFailed.html"},{"type":"type","title":"Purl.Error.SpecialCaseFailed.t/0","doc":"","ref":"Purl.Error.SpecialCaseFailed.html#t:t/0"},{"type":"extras","title":"Purl","doc":"# Purl\n\n[![hex.pm badge](https://img.shields.io/badge/Package%20on%20hex.pm-informational)](https://hex.pm/packages/purl)\n[![Documentation badge](https://img.shields.io/badge/Documentation-ff69b4)][docs]\n[![.github/workflows/branch_main.yml](https://github.com/maennchen/purl/actions/workflows/branch_main.yml/badge.svg)](https://github.com/maennchen/purl/actions/workflows/branch_main.yml)\n[![Coverage Status](https://coveralls.io/repos/github/maennchen/purl/badge.svg?branch=main)](https://coveralls.io/github/maennchen/purl?branch=main)\n\n> Implementation of the purl (package url) specification.\n\nSee [the documentation][docs].","ref":"readme.html"},{"type":"extras","title":"Usage - Purl","doc":"```elixir\niex> Purl.new(\"pkg:hex/purl\")\n{:ok, %Purl{type: \"hex\", name: \"purl\"}}\n\niex> Purl.to_string(%Purl{type: \"hex\", name: \"purl\"})\n\"pkg:hex/purl\"\n```","ref":"readme.html#usage"},{"type":"extras","title":"Installation - Purl","doc":"The package can be installed by adding `purl` to your list of dependencies in\n`mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:purl, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"License - Purl","doc":"Copyright 2023 JOSHMARTIN GmbH\n\n  Licensed under the Apache License, Version 2.0 (the \"License\");\n  you may not use this file except in compliance with the License.\n  You may obtain a copy of the License at:\n\n  >  \n\n  Unless required by applicable law or agreed to in writing, software\n  distributed under the License is distributed on an \"AS IS\" BASIS,\n  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n  See the License for the specific language governing permissions and\n  limitations under the License.\n\n[docs]: https://hexdocs.pm/purl","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}